##########
fontbakery
##########

A single-page index of all source modules is available in :ref:`modindex`.

.. toctree::
   :maxdepth: 1

   callable
   checks/index
   checkrunner
   cli
   commands/index
   constants
   fonts_public_pb2
   fonts_profile
   glyphdata
   message
   reporters/index
   profiles/index
   utils


.. automodule:: fontbakery
   :members:
   :undoc-members:
